# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-06-15 11:56
from __future__ import unicode_literals

from django.db import migrations, models

from test_app.models import TestModel


class Migration(migrations.Migration):

    dependencies = [
        ('test_app', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='testmodel',
            name='test2',
            field=models.CharField(default='', help_text='', max_length=255),
            preserve_default=False,
        ),
    ]
