# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-06-15 18:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('test_app', '0003_move_model_update'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='testmodel',
            name='test2',
        ),
        migrations.AlterField(
            model_name='testmodel',
            name='test3',
            field=models.CharField(help_text='', max_length=255),
        ),
    ]
